:- module( cultivate_basic_clear_cache, [ clear_cache/1 ]).
/**
*	clear_cache(+ContextModule)
*	retracts  all dynamic predicates defined in module ContextModule	
*/
clear_cache(ContextModule)  :-
   ground(ContextModule),
      
   forall( 
     dynamic_predicate(ContextModule,Head), 
     retractall(ContextModule:Head) 
   ).


% dynamic_predicate(?Module,?Head)
% true if Head is dynamic declared in Module
% see CTC file .../ct_core/utils/utils4modules.pl 
dynamic_predicate(Module,Head) :-
   declared_in_module(Module, Head),
   predicate_property(Module:Head, dynamic).
   


/**
 * declared_in_module(+Module, +Head) is det.
 * declared_in_module(+Module, ?Head) is nondet.
 * declared_in_module(?Module, ?Head) is nondet.
 *  
 * Determine whether the predicate indicated by Head has a *local*
 * (non-imported) declaration in the module Module. The predicate 
 * succeeds if there is at least a declaration (but possibly no  
 * single clause) of the predicate in the module. If you want it to  
 * fail you must abolish the predicate declaration, not just  
 * retract all its clauses. See the built-ins Prolog predicates   
 * abolish/1, abolish/1, retractall/1, retract/1
 */  
declared_in_module(Module, Head) :-
   current_predicate(_, Module:Head),                    % Head is declared
   \+ predicate_property(Module:Head, imported_from(_)). % but not imported
   