/****************************************************
% File Name: pronto_morph_irreg_verb.pl
% Author: Jason Schlachter (ai@uga.edu)(www.arches.uga.edu/~ai)

% Released: May 8th, 2003
% Artificial Intelligence Center (www.ai.uga.edu)
% ***see pronto_morph.pdf for documentation
%
% This file is to be used as part of the morphological analyzer
% that is a component of ProNTo (Prolog Natural Language
% Toolkit), made at the Artificial Intelligence Center of
% the University of Georgia (www.ai.uga.edu).
%
% Special thanks:
% 1)To the wordnet project for their list words that are exceptions to the spelling rules.
% 2)To Dr. Covington for his guidence on the project.
******************************************************/


:-multifile( irregular_form/3 ).

% irregular_form(+Atom,-Tail,-List)
%  Interprets an irregular form (as an open list)


irregular_form( ran,      X, [run, -past  | X ]).
irregular_form( run,      X, [run, -en  | X ]).
irregular_form( eaten,    X, [eat, -en | X] ).
irregular_form( has,      X, [have, -sg3  | X] ).
irregular_form( had,      X, [have, -ed | X] ).

% contractions minus the apostrophe
%
irregular_form( cant,    X, [can,   not | X] ).
irregular_form( ill,    X, [i,   will | X] ).
irregular_form( didnt,    X, [did,   not | X] ).
irregular_form( doesnt,   X, [do, -sg3, not | X ]).    % this one has three
irregular_form( wouldnt,    X, [would,   not | X] ).
irregular_form( couldnt,    X, [could,   not | X] ).
irregular_form( shouldnt,    X, [should,   not | X] ).
irregular_form( wasnt,    X, [is, -past, not | X] ).
irregular_form( isnt,    X, [is,   not | X] ).
irregular_form( mustnt,    X, [must,   not | X] ).
irregular_form( youll,    X, [you,   will | X] ).


% adapted from modified exception list from wordnet
%
irregular_form( abode,X,[abide,-past| X ]).
irregular_form( arcked,X,[arc,-ed| X ]).
irregular_form( arcking,X,[arc,-ing| X ]).
irregular_form( arose,X,[arise,-past| X ]).
irregular_form( ate,X,[eat,-past| X ]).
irregular_form( awoke,X,[awake,-past| X ]).
irregular_form( awoken,X,[awake,-en| X ]).
irregular_form( backbit,X,[backbite,-past| X ]).
irregular_form( backbitten,X,[backbite,-en| X ]).
irregular_form( backslid,X,[backslide,-past| X ]).
irregular_form( backslidden,X,[backslide,-en| X ]).
irregular_form( bade,X,[bid,-past| X ]).
irregular_form( beaten,X,[beat,-en| X ]).
irregular_form( became,X,[become,-past| X ]).
irregular_form( befallen,X,[befall,-en| X ]).
irregular_form( befell,X,[befall,-past| X ]).
irregular_form( began,X,[begin,-past| X ]).
irregular_form( begat,X,[beget,-past| X ]).
irregular_form( begot,X,[beget,-past| X ]).
irregular_form( begotten,X,[beget,-en| X ]).
irregular_form( begun,X,[begin,-en| X ]).
irregular_form( beheld,X,[behold,-past| X ]).
irregular_form( beholden,X,[behold,-en| X ]).
irregular_form( belying,X,[belie,-ing| X ]).
irregular_form( bent,X,[bend,-past| X ]).
irregular_form( besought,X,[beseech,-past| X ]).
irregular_form( bespoke,X,[bespeak,-past| X ]).
irregular_form( bespoken,X,[bespeak,-en| X ]).
irregular_form( bethought,X,[bethink,-past| X ]).
irregular_form( betook,X,[betake,-past| X ]).
irregular_form( bidden,X,[bid,-en| X ]).
irregular_form( bit,X,[bite,-past| X ]).
irregular_form( bitten,X,[bite,-en| X ]).
irregular_form( bivouacked,X,[bivouac,-past| X ]).
irregular_form( bivouacking,X,[bivouac,-ing| X ]).
irregular_form( bled,X,[bleed,-past| X ]).
irregular_form( blest,X,[bless,-past| X ]).
irregular_form( blew,X,[blow,-past| X ]).
irregular_form( blown,X,[blow,-en| X ]).
irregular_form( bore,X,[bear,-past| X ]).
irregular_form( born,X,[bear,-en| X ]).
irregular_form( borne,X,[bear,-en| X ]).
irregular_form( bought,X,[buy,-past| X ]).
irregular_form( bound,X,[bind,-past| X ]).
irregular_form( bred,X,[breed,-past| X ]).
irregular_form( broke,X,[break,-past| X ]).
irregular_form( broken,X,[break,-en| X ]).
irregular_form( brought,X,[bring,-past| X ]).
irregular_form( browbeaten,X,[browbeat,-en| X ]).
irregular_form( built,X,[build,-past| X ]).
irregular_form( burnt,X,[burn,-past| X ]).
irregular_form( bypast,X,[bypass,-past| X ]).
irregular_form( came,X,[come,-past| X ]).
irregular_form( caught,X,[catch,-past| X ]).
irregular_form( chevied,X,[chivy,-past| X ]).
irregular_form( chevies,X,[chivy,-sg| X ]).
irregular_form( chevying,X,[chivy,-ing| X ]).
irregular_form( chose,X,[choose,-past| X ]).
irregular_form( chosen,X,[choose,-en| X ]).
irregular_form( clad,X,[clothe,-past| X ]).
irregular_form( cleft,X,[cleave,-past| X ]).
irregular_form( clept,X,[clepe,-past| X ]).
irregular_form( clove,X,[cleave,-past| X ]).
irregular_form( cloven,X,[cleave,-en| X ]).
irregular_form( clung,X,[cling,-past| X ]).
irregular_form( countersank,X,[countersink,-past| X ]).
irregular_form( countersunk,X,[countersink,-past| X ]).
irregular_form( crept,X,[creep,-past| X ]).
irregular_form( crossbred,X,[crossbreed,-past| X ]).
irregular_form( curst,X,[curse,-past| X ]).
irregular_form( dealt,X,[deal,-past| X ]).
irregular_form( did,X,[do,-past| X ]).
irregular_form( disenthralls,X,[disenthral,-sg| X ]).
irregular_form( done,X,[do,-past| X ]).
irregular_form( dought,X,[dow,-past| X ]).
irregular_form( dove,X,[dive,-past| X ]).
irregular_form( drank,X,[drink,-past| X ]).
irregular_form( drawn,X,[draw,-en| X ]).
irregular_form( dreamt,X,[dream,-past| X ]).
irregular_form( drew,X,[draw,-past| X ]).
irregular_form( drove,X,[drive,-past| X ]).
irregular_form( drunk,X,[drink,-past| X ]).
irregular_form( dug,X,[dig,-past| X ]).
irregular_form( dwelt,X,[dwell,-past| X ]).
irregular_form( dying,X,[die,-ing| X ]).
irregular_form( enwound,X,[enwind,-past| X ]).
irregular_form( fallen,X,[fall,-en| X ]).
irregular_form( fed,X,[feed,-past| X ]).
irregular_form( fell,X,[fall,-past| X ]).
irregular_form( fled,X,[flee,-past| X ]).
irregular_form( flew,X,[fly,-past| X ]).
irregular_form( floodlit,X,[floodlight,-past| X ]).
irregular_form( flown,X,[fly,-en| X ]).
irregular_form( flung,X,[fling,-past| X ]).
irregular_form( forbad,X,[forbid,-past| X ]).
irregular_form( forbade,X,[forbid,-past| X ]).
irregular_form( forbidden,X,[forbid,-en| X ]).
irregular_form( forbore,X,[forbear,-past| X ]).
irregular_form( forborne,X,[forbear,-past| X ]).
irregular_form( foregone,X,[forego,-past| X ]).
irregular_form( foreknew,X,[foreknow,-past| X ]).
irregular_form( foreknown,X,[foreknow,-en| X ]).
irregular_form( foreran,X,[forerun,-past| X ]).
irregular_form( foresaw,X,[foresee,-past| X ]).
irregular_form( foreshown,X,[foreshow,-en| X ]).
irregular_form( forespoke,X,[forespeak,-past| X ]).
irregular_form( forespoken,X,[forespeak,-en| X ]).
irregular_form( foretold,X,[foretell,-past| X ]).
irregular_form( forewent,X,[forego,-past| X ]).
irregular_form( forgave,X,[forgive,-past| X ]).
irregular_form( forgone,X,[forgo,-past| X ]).
irregular_form( forgot,X,[forget,-past| X ]).
irregular_form( forgotten,X,[forget,-en| X ]).
irregular_form( forsook,X,[forsake,-past| X ]).
irregular_form( forspoke,X,[forspeak,-past| X ]).
irregular_form( forspoken,X,[forspeak,-en| X ]).
irregular_form( forswore,X,[forswear,-past| X ]).
irregular_form( forsworn,X,[forswear,-en| X ]).
irregular_form( forwent,X,[forgo,-past| X ]).
irregular_form( fought,X,[fight,-past| X ]).
irregular_form( found,X,[find,-past| X ]).
irregular_form( frolicked,X,[frolic,-past| X ]).
irregular_form( frolicking,X,[frolic,-ing| X ]).
irregular_form( froze,X,[freeze,-past| X ]).
irregular_form( frozen,X,[freeze,-en| X ]).
irregular_form( gainsaid,X,[gainsay,-past| X ]).
irregular_form( gan,X,[gin,-past| X ]).
irregular_form( gave,X,[give,-past| X ]).
irregular_form( gelt,X,[geld,-past| X ]).
irregular_form( ghostwritten,X,[ghostwrite,-en| X ]).
irregular_form( ghostwrote,X,[ghostwrite,-past| X ]).
irregular_form( gilt,X,[gild,-past| X ]).
irregular_form( girt,X,[gird,-past| X ]).
irregular_form( gnawn,X,[gnaw,-en| X ]).
irregular_form( gone,X,[go,-past| X ]).
irregular_form( got,X,[get,-past| X ]).
irregular_form( gotten,X,[get,-en| X ]).
irregular_form( grew,X,[grow,-past| X ]).
irregular_form( gript,X,[grip,-past| X ]).
irregular_form( ground,X,[grind,-past| X ]).
irregular_form( grown,X,[grow,-en| X ]).
irregular_form( hacksawn,X,[hacksaw,-en| X ]).
irregular_form( hamstrung,X,[hamstring,-past| X ]).
irregular_form( handfed,X,[handfeed,-past| X ]).
irregular_form( held,X,[hold,-past| X ]).
irregular_form( hewn,X,[hew,-en| X ]).
irregular_form( hid,X,[hide,-past| X ]).
irregular_form( hidden,X,[hide,-en| X ]).
irregular_form( hogtying,X,[hogtie,-ing| X ]).
irregular_form( honied,X,[honey,-past| X ]).
irregular_form( hove,X,[heave,-past| X ]).
irregular_form( hung,X,[hang,-past| X ]).
irregular_form( inbred,X,[inbreed,-past| X ]).
irregular_form( indwelt,X,[indwell,-past| X ]).
irregular_form( inlaid,X,[inlay,-past| X ]).
irregular_form( interbred,X,[interbreed,-past| X ]).
irregular_form( interlaid,X,[interlay,-past| X ]).
irregular_form( interpled,X,[interplead,-past| X ]).
irregular_form( interwove,X,[interweave,-past| X ]).
irregular_form( interwoven,X,[interweave,-en| X ]).
irregular_form( inwove,X,[inweave,-past| X ]).
irregular_form( inwoven,X,[inweave,-en| X ]).
irregular_form( kent,X,[ken,-past| X ]).
irregular_form( kept,X,[keep,-past| X ]).
irregular_form( knelt,X,[kneel,-past| X ]).
irregular_form( knew,X,[know,-past| X ]).
irregular_form( known,X,[know,-en| X ]).
irregular_form( ladyfied,X,[ladify,-past| X ]).
irregular_form( ladyfies,X,[ladify,-sg| X ]).
irregular_form( ladyfying,X,[ladify,-ing| X ]).
irregular_form( laid,X,[lay,-past| X ]).
irregular_form( lain,X,[lie,-en| X ]).
irregular_form( lay,X,[lie,-past| X ]).
irregular_form( leant,X,[lean,-past| X ]).
irregular_form( leapt,X,[leap,-past| X ]).
irregular_form( learnt,X,[learn,-past| X ]).
irregular_form( led,X,[lead,-past| X ]).
irregular_form( left,X,[leave,-past| X ]).
irregular_form( lent,X,[lend,-past| X ]).
irregular_form( lit,X,[light,-past| X ]).
irregular_form( lost,X,[lose,-past| X ]).
irregular_form( lying,X,[lie,-ing| X ]).
irregular_form( made,X,[make,-past| X ]).
irregular_form( meant,X,[mean,-past| X ]).
irregular_form( met,X,[meet,-past| X ]).
irregular_form( mimicked,X,[mimic,-past| X ]).
irregular_form( mimicking,X,[mimic,-ing| X ]).
irregular_form( misbecame,X,[misbecome,-past| X ]).
irregular_form( misdealt,X,[misdeal,-past| X ]).
irregular_form( misgave,X,[misgive,-past| X ]).
irregular_form( mislaid,X,[mislay,-past| X ]).
irregular_form( misled,X,[mislead,-past| X ]).
irregular_form( mispled,X,[misplead,-past| X ]).
irregular_form( misspelt,X,[misspell,-past| X ]).
irregular_form( misspent,X,[misspend,-past| X ]).
irregular_form( mistook,X,[mistake,-past| X ]).
irregular_form( misunderstood,X,[misunderstand,-past| X ]).
irregular_form( molten,X,[melt,-en| X ]).
irregular_form( mown,X,[mow,-en| X ]).
irregular_form( outbidden,X,[outbid,-en| X ]).
irregular_form( outbred,X,[outbreed,-past| X ]).
irregular_form( outdid,X,[outdo,-past| X ]).
irregular_form( outdone,X,[outdo,-en| X ]).
irregular_form( outdrawn,X,[outdraw,-en| X ]).
irregular_form( outdrew,X,[outdraw,-past| X ]).
irregular_form( outfought,X,[outfight,-past| X ]).
irregular_form( outgone,X,[outgo,-en| X ]).
irregular_form( outgrew,X,[outgrow,-past| X ]).
irregular_form( outgrown,X,[outgrow,-en| X ]).
irregular_form( outlaid,X,[outlay,-past| X ]).
irregular_form( outran,X,[outrun,-past| X ]).
irregular_form( outridden,X,[outride,-en| X ]).
irregular_form( outrode,X,[outride,-past| X ]).
irregular_form( outshone,X,[outshine,-past| X ]).
irregular_form( outshot,X,[outshoot,-past| X ]).
irregular_form( outsold,X,[outsell,-past| X ]).
irregular_form( outstood,X,[outstand,-past| X ]).
irregular_form( outthought,X,[outthink,-past| X ]).
irregular_form( outwent,X,[outgo,-past| X ]).
irregular_form( outwore,X,[outwear,-past| X ]).
irregular_form( outworn,X,[outwear,-en| X ]).
irregular_form( overbidden,X,[overbid,-en| X ]).
irregular_form( overblew,X,[overblow,-past| X ]).
irregular_form( overblown,X,[overblow,-en| X ]).
irregular_form( overbore,X,[overbear,-past| X ]).
irregular_form( overborne,X,[overbear,-en| X ]).
irregular_form( overbuilt,X,[overbuild,-past| X ]).
irregular_form( overcame,X,[overcome,-past| X ]).
irregular_form( overdid,X,[overdo,-past| X ]).
irregular_form( overdone,X,[overdo,-past| X ]).
irregular_form( overdrawn,X,[overdraw,-en| X ]).
irregular_form( overdrew,X,[overdraw,-past| X ]).
irregular_form( overdrove,X,[overdrive,-past| X ]).
irregular_form( overflew,X,[overfly,-past| X ]).
irregular_form( overflown,X,[overfly,-en| X ]).
irregular_form( overgrew,X,[overgrow,-past| X ]).
irregular_form( overgrown,X,[overgrow,-en| X ]).
irregular_form( overhung,X,[overhang,-past| X ]).
irregular_form( overlaid,X,[overlay,-past| X ]).
irregular_form( overlain,X,[overlie,-en| X ]).
irregular_form( overlay,X,[overlie,-past| X ]).
irregular_form( overlying,X,[overlie,-ing| X ]).
irregular_form( overpaid,X,[overpay,-past| X ]).
irregular_form( overpast,X,[overpass,-past| X ]).
irregular_form( overran,X,[overrun,-past| X ]).
irregular_form( overridden,X,[override,-en| X ]).
irregular_form( overrode,X,[override,-past| X ]).
irregular_form( oversaw,X,[oversee,-past| X ]).
irregular_form( oversewn,X,[oversew,-en| X ]).
irregular_form( overshot,X,[overshoot,-past| X ]).
irregular_form( overslept,X,[oversleep,-past| X ]).
irregular_form( oversold,X,[oversell,-past| X ]).
irregular_form( overspent,X,[overspend,-past| X ]).
irregular_form( overspilt,X,[overspill,-past| X ]).
irregular_form( overthrew,X,[overthrow,-past| X ]).
irregular_form( overthrown,X,[overthrow,-past| X ]).
irregular_form( overtook,X,[overtake,-past| X ]).
irregular_form( overwound,X,[overwind,-past| X ]).
irregular_form( overwritten,X,[overwrite,-en| X ]).
irregular_form( overwrote,X,[overwrite,-past| X ]).
irregular_form( paid,X,[pay,-past| X ]).
irregular_form( panicked,X,[panic,-past| X ]).
irregular_form( panicking,X,[panic,-ing| X ]).
irregular_form( partook,X,[partake,-past| X ]).
irregular_form( pasquilled,X,[pasquinade,-past| X ]).
irregular_form( pasquilling,X,[pasquinade,-ing| X ]).
irregular_form( pent,X,[pen,-past| X ]).
irregular_form( physicked,X,[physic,-past| X ]).
irregular_form( physicking,X,[physic,-ing| X ]).
irregular_form( picnicked,X,[picnic,-past| X ]).
irregular_form( picnicking,X,[picnic,-ing| X ]).
irregular_form( pled,X,[plead,-past| X ]).
irregular_form( prepaid,X,[prepay,-past| X ]).
irregular_form( programmes,X,[program,-sg| X ]).
irregular_form( prologed,X,[prologue,-past| X ]).
irregular_form( prologing,X,[prologue,-ing| X ]).
irregular_form( prologs,X,[prologue,-sg| X ]).
irregular_form( quartersawn,X,[quartersaw,-en| X ]).
irregular_form( rang,X,[ring,-past| X ]).
irregular_form( rebuilt,X,[rebuild,-past| X ]).
irregular_form( redid,X,[redo,-past| X ]).
irregular_form( redone,X,[redo,-past| X ]).
irregular_form( reft,X,[reave,-past| X ]).
irregular_form( remade,X,[remake,-past| X ]).
irregular_form( rent,X,[rend,-past| X ]).
irregular_form( repaid,X,[repay,-past| X ]).
irregular_form( reran,X,[rerun,-past| X ]).
irregular_form( resat,X,[resit,-past| X ]).
irregular_form( resewn,X,[resew,-en| X ]).
irregular_form( rethought,X,[rethink,-past| X ]).
irregular_form( retold,X,[retell,-past| X ]).
irregular_form( retook,X,[retake,-past| X ]).
irregular_form( rewound,X,[rewind,-past| X ]).
irregular_form( rewritten,X,[rewrite,-en| X ]).
irregular_form( rewrote,X,[rewrite,-past| X ]).
irregular_form( ridden,X,[ride,-en| X ]).
irregular_form( rode,X,[ride,-past| X ]).
irregular_form( rose,X,[rise,-past| X ]).
irregular_form( rove,X,[reeve,-past| X ]).
irregular_form( rung,X,[ring,-past| X ]).
irregular_form( said,X,[say,-past| X ]).
irregular_form( sang,X,[sing,-past| X ]).
irregular_form( sank,X,[sink,-past| X ]).
irregular_form( sat,X,[sit,-past| X ]).
irregular_form( saw,X,[see,-past| X ]).
irregular_form( sawn,X,[saw,-en| X ]).
irregular_form( sent,X,[send,-past| X ]).
irregular_form( sewn,X,[sew,-en| X ]).
irregular_form( shat,X,[shit,-past| X ]).
irregular_form( shellacked,X,[shellac,-past| X ]).
irregular_form( shellacking,X,[shellac,-ing| X ]).
irregular_form( shent,X,[shend,-past| X ]).
irregular_form( shewn,X,[shew,-en| X ]).
irregular_form( shod,X,[shoe,-past| X ]).
irregular_form( shone,X,[shine,-past| X ]).
irregular_form( shook,X,[shake,-past| X ]).
irregular_form( shot,X,[shoot,-past| X ]).
irregular_form( shown,X,[show,-en| X ]).
irregular_form( shrank,X,[shrink,-past| X ]).
irregular_form( shrove,X,[shrive,-past| X ]).
irregular_form( shrunk,X,[shrink,-past| X ]).
irregular_form( shrunken,X,[shrink,-en| X ]).
irregular_form( sicked,X,[sic,-past| X ]).
irregular_form( sicking,X,[sic,-ing| X ]).
irregular_form( sightsaw,X,[sightsee,-past| X ]).
irregular_form( skydove,X,[skydive,-past| X ]).
irregular_form( slain,X,[slay,-past| X ]).
irregular_form( slept,X,[sleep,-past| X ]).
irregular_form( slew,X,[slay,-past| X ]).
irregular_form( slid,X,[slide,-past| X ]).
irregular_form( slidden,X,[slide,-en| X ]).
irregular_form( slung,X,[sling,-past| X ]).
irregular_form( slunk,X,[slink,-past| X ]).
irregular_form( smelt,X,[smell,-past| X ]).
irregular_form( smit,X,[smite,-past| X ]).
irregular_form( smitten,X,[smite,-en| X ]).
irregular_form( smote,X,[smite,-sg| X ]).
irregular_form( sold,X,[sell,-past| X ]).
irregular_form( soothsaid,X,[soothsay,-past| X ]).
irregular_form( sought,X,[seek,-past| X ]).
irregular_form( sown,X,[sow,-en| X ]).
irregular_form( spat,X,[spit,-past| X ]).
irregular_form( sped,X,[speed,-past| X ]).
irregular_form( spellbound,X,[spellbind,-past| X ]).
irregular_form( spelt,X,[spell,-past| X ]).
irregular_form( spent,X,[spend,-past| X ]).
irregular_form( spilt,X,[spill,-past| X ]).
irregular_form( spoilt,X,[spoil,-past| X ]).
irregular_form( spoke,X,[speak,-past| X ]).
irregular_form( spoken,X,[speak,-en| X ]).
irregular_form( spotlit,X,[spotlight,-past| X ]).
irregular_form( sprang,X,[spring,-past| X ]).
irregular_form( sprung,X,[spring,-past| X ]).
irregular_form( spun,X,[spin,-past| X ]).
irregular_form( stank,X,[stink,-past| X ]).
irregular_form( stilettoeing,X,[stiletto,-ing| X ]).
irregular_form( stole,X,[steal,-past| X ]).
irregular_form( stolen,X,[steal,-en| X ]).
irregular_form( stood,X,[stand,-past| X ]).
irregular_form( stove,X,[stave,-past| X ]).
irregular_form( strewn,X,[strew,-en| X ]).
irregular_form( stridden,X,[stride,-en| X ]).
irregular_form( strode,X,[stride,-past| X ]).
irregular_form( strove,X,[strive,-past| X ]).
irregular_form( strown,X,[strow,-past| X ]).
irregular_form( struck,X,[strike,-past| X ]).
irregular_form( strung,X,[string,-past| X ]).
irregular_form( stuck,X,[stick,-past| X ]).
irregular_form( stung,X,[sting,-past| X ]).
irregular_form( stunk,X,[stink,-past| X ]).
irregular_form( stymying,X,[stymie,-ing| X ]).
irregular_form( sung,X,[sing,-past| X ]).
irregular_form( sunk,X,[sink,-past| X ]).
irregular_form( sunken,X,[sink,-en| X ]).
irregular_form( swam,X,[swim,-past| X ]).
irregular_form( swept,X,[sweep,-past| X ]).
irregular_form( swollen,X,[swell,-en| X ]).
irregular_form( swore,X,[swear,-past| X ]).
irregular_form( sworn,X,[swear,-past| X ]).
irregular_form( swum,X,[swim,-past| X ]).
irregular_form( swung,X,[swing,-past| X ]).
irregular_form( talcked,X,[talc,-past| X ]).
irregular_form( talcking,X,[talc,-ing| X ]).
irregular_form( taught,X,[teach,-past| X ]).
irregular_form( taxying,X,[taxi,-ing| X ]).
irregular_form( thought,X,[think,-past| X ]).
irregular_form( threw,X,[throw,-past| X ]).
irregular_form( throve,X,[thrive,-past| X ]).
irregular_form( thrown,X,[throw,-past| X ]).
irregular_form( told,X,[tell,-past| X ]).
irregular_form( took,X,[take,-past| X ]).
irregular_form( tore,X,[tear,-past| X ]).
irregular_form( torn,X,[tear,-past| X ]).
irregular_form( torrify,X,[torrefy,-past| X ]).
irregular_form( trafficked,X,[traffic,-past| X ]).
irregular_form( trafficking,X,[traffic,-ing| X ]).
irregular_form( trameled,X,[trammel,-past| X ]).
irregular_form( trameling,X,[trammel,-ing| X ]).
irregular_form( tramelled,X,[trammel,-past| X ]).
irregular_form( tramelling,X,[trammel,-ing| X ]).
irregular_form( transfixt,X,[transfix,-past| X ]).
irregular_form( trod,X,[tread,-past| X ]).
irregular_form( trodden,X,[tread,-en| X ]).
irregular_form( tying,X,[tie,-ing| X ]).
irregular_form( typewritten,X,[typewrite,-en| X ]).
irregular_form( typewrote,X,[typewrite,-past| X ]).
irregular_form( unbent,X,[unbend,-past| X ]).
irregular_form( unbound,X,[unbind,-past| X ]).
irregular_form( unclad,X,[unclothe,-past| X ]).
irregular_form( underbought,X,[underbuy,-past| X ]).
irregular_form( underfed,X,[underfeed,-past| X ]).
irregular_form( undergirt,X,[undergird,-past| X ]).
irregular_form( undergone,X,[undergo,-past| X ]).
irregular_form( underlaid,X,[underlay,-past| X ]).
irregular_form( underlain,X,[underlie,-past| X ]).
irregular_form( underlay,X,[underlie,-past| X ]).
irregular_form( underlying,X,[underlie,-ing| X ]).
irregular_form( underpaid,X,[underpay,-past| X ]).
irregular_form( undershot,X,[undershoot,-past| X ]).
irregular_form( undersold,X,[undersell,-past| X ]).
irregular_form( understood,X,[understand,-past| X ]).
irregular_form( undertook,X,[undertake,-past| X ]).
irregular_form( underwent,X,[undergo,-past| X ]).
irregular_form( underwritten,X,[underwrite,-en| X ]).
irregular_form( underwrote,X,[underwrite,-past| X ]).
irregular_form( undid,X,[undo,-past| X ]).
irregular_form( undone,X,[undo,-past| X ]).
irregular_form( unfroze,X,[unfreeze,-past| X ]).
irregular_form( unfrozen,X,[unfreeze,-en| X ]).
irregular_form( unlaid,X,[unlay,-past| X ]).
irregular_form( unlearnt,X,[unlearn,-past| X ]).
irregular_form( unmade,X,[unmake,-past| X ]).
irregular_form( unrove,X,[unreeve,-past| X ]).
irregular_form( unsaid,X,[unsay,-past| X ]).
irregular_form( unslung,X,[unsling,-past| X ]).
irregular_form( unspoke,X,[unspeak,-past| X ]).
irregular_form( unstrung,X,[unstring,-past| X ]).
irregular_form( unstuck,X,[unstick,-past| X ]).
irregular_form( unswore,X,[unswear,-past| X ]).
irregular_form( unsworn,X,[unswear,-past| X ]).
irregular_form( untaught,X,[unteach,-past| X ]).
irregular_form( unthought,X,[unthink,-past| X ]).
irregular_form( untrod,X,[untread,-past| X ]).
irregular_form( untrodden,X,[untread,-en| X ]).
irregular_form( untying,X,[untie,-ing| X ]).
irregular_form( unwound,X,[unwind,-past| X ]).
irregular_form( upbuilt,X,[upbuild,-past| X ]).
irregular_form( upheld,X,[uphold,-past| X ]).
irregular_form( uphove,X,[upheave,-past| X ]).
irregular_form( uprose,X,[uprise,-past| X ]).
irregular_form( upsprang,X,[upspring,-past| X ]).
irregular_form( upsprung,X,[upspring,-past| X ]).
irregular_form( upswept,X,[upsweep,-past| X ]).
irregular_form( upswollen,X,[upswell,-en| X ]).
irregular_form( upswung,X,[upswing,-past| X ]).
irregular_form( vying,X,[vie,-ing| X ]).
irregular_form( waylaid,X,[waylay,-past| X ]).
irregular_form( went,X,[go,-past| X ]).
irregular_form( wept,X,[weep,-past| X ]).
irregular_form( winterfed,X,[winterfeed,-past| X ]).
irregular_form( wiredrawn,X,[wiredraw,-en| X ]).
irregular_form( wiredrew,X,[wiredraw,-past| X ]).
irregular_form( withdrawn,X,[withdraw,-en| X ]).
irregular_form( withdrew,X,[withdraw,-past| X ]).
irregular_form( withheld,X,[withhold,-past| X ]).
irregular_form( withstood,X,[withstand,-past| X ]).
irregular_form( woke,X,[wake,-past| X ]).
irregular_form( woken,X,[wake,-en| X ]).
irregular_form( won,X,[win,-past| X ]).
irregular_form( wore,X,[wear,-past| X ]).
irregular_form( worn,X,[wear,-en| X ]).
irregular_form( wound,X,[wind,-past| X ]).
irregular_form( wove,X,[weave,-past| X ]).
irregular_form( woven,X,[weave,-en| X ]).
irregular_form( written,X,[write,-en| X ]).
irregular_form( wrote,X,[write,-past| X ]).
irregular_form( wrought,X,[work,-past| X ]).
irregular_form( wrung,X,[wring,-past| X ]).
irregular_form( ycleped,X,[clepe,-past| X ]).
irregular_form( yclept,X,[clepe,-past| X ]).
