:- module('cultivate_concepts_term_introduction', [
													generate_term_introduced/1 , 
												    is_term_introduced/3,    % (Context,Term,Bool)
													context_has_introduced_term/2% (Context,Term)
        
													]).
:- use_module(term_model).

:- use_module('../util/termcache_utils').
    

:- dynamic context_has_introduced_term/2.

% generate_term_introduced(+ContextModule)
generate_term_introduced(_):-
    %atom_concat(ContextModule,'_introduced',AssertionModule),
     cleanup,
     term_introduced_in_class__,
     term_introduced_in_package__.
     
     
term_introduced_in_class__:-    
     term_is_introduced_in_class(Context, Term),
         assert( context_has_introduced_term(Context, Term) ),
     fail.
term_introduced_in_class__.

term_introduced_in_package__:-     
     term_is_introduced_in_package(Context,Term),
         assert_unique( context_has_introduced_term(Context,Term)),
     fail.
term_introduced_in_package__.
    %generate_term_introduced__,  % 3,519,916 inferences, 0.656 CPU in 0.652 seconds (101% CPU, 5363682 Lips)
%    generate_term_introduced_package__. % % 514 inferences, 0.000 CPU in 0.000 seconds (?% CPU, Infinite Lips)
% ================================================================     
cleanup:-
     retractall(context_has_introduced_term(_,_)).
     
      
 
 
 
% JN: Todo refactor and more generic, just a hack for getting introduced on packagelevel ready for labdemo
%generate_term_introduced_package__:-
%generate_term_introduced_package__.
 
% ? ?      
term_is_introduced_in_package(Context,Term):-
     packageT(Context,_), 
     relevant_context_element(Context),
     package_contains_type(Context,ClassId),
     context_has_introduced_term(ClassId,Term).
 

% term_is_introduced_in_class(+ClassId, ?Term)
% A term is introduced by a class if the class name is
% itself a single term that cannot be decomposed further.
% Arg2 is the downcased version of the classname of Arg1.
term_is_introduced_in_class(ClassId, LowerName) :-
    relevant_context_element(ClassId),
    type_name(ClassId,ClassName),
    downcase_atom(ClassName,LowerName),
    context_has_term(ClassId,LowerName,_). 

term_is_introduced_in_class(ClassId, Term) :-
    relevant_context_element(ClassId),
    once((context_has_term(ClassId,Term,_),
    	  term_is_introduced_in_a_method(ClassId,Term))).
     


% term_is_introduced_in_a_method(+ClassId,?Term)
% A Term is introduced in a method of a class, if the methodname is itself a single term
% The method modifier must be protected or public.
term_is_introduced_in_a_method(ClassId,Term):-
      ri_methodT_parent(ClassId,MethodID),
      methodT(MethodID,ClassId,Term,_,_,_,_),
      ( modifierT(MethodID,public) ; modifierT(MethodID,protected) ),
	  is_compound(Term).
      
    
is_term_introduced(Context,Term, Bool) :-
    context_has_introduced_term(Context,Term) 
    -> Bool = true
     ; Bool = false.

