package org.cs3.cultivate.dev.logging;

public abstract aspect Logging {

	abstract pointcut scope();

	abstract pointcut dontJudgeCode();

	declare warning: scope() && !dontJudgeCode() && call(* *..println(..)): 
		"Logging should be done by a logging aspect and not directly!";

	protected String prefix = ">>>";

	private static int indentionLevel = 0;

	public Logging(String prefix){
		this.prefix = prefix;
	}
	
	protected void log(String message) {
		String prolog = prefix + " ";
		for (int i = 0; i < indentionLevel; i++) {
			prolog += "  ";
		}
		System.out.print(prolog);
		System.out.println(message);
	}

	protected void logBefore(String message) {
		log(message);
		indentionLevel++;
	}

	protected void logAfter(String message) {
		indentionLevel--;
		log(message);
	}

	protected String simpleClassName(Object obj) {
		if (obj == null) return "NULL";
		return obj.getClass().getSimpleName();
	}

	abstract pointcut interestingExecution();

	Object around(): interestingExecution(){
		logBefore("" + thisJoinPointStaticPart.getSignature().toShortString());
		Object result = proceed();
		logAfter("" + thisJoinPointStaticPart.getSignature().toShortString());
		return result;
	}

	abstract pointcut interestingCall();

	Object around(Object caller, Object called): interestingCall() && this(caller) && target(called){
		logBefore("" + simpleClassName(caller) + " calls "
				+ thisJoinPointStaticPart.getSignature().toShortString());
		Object result = proceed(caller, called);
		logAfter("" + thisJoinPointStaticPart.getSignature().toShortString()
				+ " resulted in " + result);
		return result;
	}

}
