:- multifile query_description/3.
:- multifile metric_/3.
:- multifile metric_attributes/2.

query_description(class_instability, metric, 'degree of class instability').
metric_attributes(class_instability, float(range(0,1), defaultthresholds(0,1))).

/** *****************************************************************
  * class_instability(+ClassId, ?Instability)
  *
  * Returns the ratio of efferent couplings to total number of
  * (afferent and efferent) couplings for the class ClassId
  * If the package has no couplings at all it returns 0.
  */
metric_(class_instability, ClassId, Instability) :-
    internal_type(ClassId),
    
    findall(ReferencedClass,
             classDependency(ClassId, ReferencedClass, _),
             AfferentClassCouplings),
    sort(AfferentClassCouplings, AfferentClasses),
    length(AfferentClasses, AfferentCouplings),
    
    findall(ReferencingClass,
             classDependency(ReferencingClass, ClassId, _),
             EfferentClassCouplings),
    sort(EfferentClassCouplings, EfferentClasses),
    length(EfferentClasses, EfferentCouplings),
    
    AllReferenceClasses is AfferentCouplings + EfferentCouplings,
    divide(EfferentCouplings, AllReferenceClasses, Instability,0).